# Bolt12 Offer Decoding Library

Python binding for the [Bolt12 Offer Decoding Library](https://github.com/21M4TW/b12od). The library can be built
using the python_binding target from the main directory of the repository.

It can then be tested using
```
. venv/bin/activate
pytest
```

Sample code is also located in [examples](https://github.com/21M4TW/b12od/tree/main/python/examples).
